@@ -1,11 +1,11 @@
 from typing import (
     Any,
     Callable,
+    IO,
     Iterable,
     Iterator,
     MutableSet,
     Optional,
-    TextIO,
     TypeVar,
 )
 
@@ -458,13 +458,14 @@ class Settings(Bundle, Lockable):
 
         self._update_notification_enabled = _update_notification_enabled
 
-    def save(self, file: TextIO, blanklines: bool = False) -> None:
+    def save(self, file: IO[str], blanklines: bool = False) -> None:
         """
         Writes the contents of this Settings instance and its subsections in
         text form to the given file object.
 
         Args:
             file: A text file object where to save this Settings instance.
+
             blanklines: Whether to add a blank line before section headings.
 
         Returns:
@@ -480,7 +481,7 @@ class Settings(Bundle, Lockable):
 
         save_to_file(file, self.dumpFields(), blanklines=blanklines)
 
-    def load(self, file: TextIO) -> None:
+    def load(self, file: IO[str]) -> None:
         """
         Loads settings from the given text file object.
 
